## ----setup, message=FALSE, warning=FALSE--------------------------------------
#| code-fold: true
#| code-summary: "Session Settings"
#| label: load-packages

# Graphs----
face_text='plain'
face_title='plain'
size_title = 14
size_text = 11
legend_size = 11



## .justify {
##   text-align: justify !important
## }

## ----libraries, message=FALSE-------------------------------------------------

required_libraries <- c(
  "tidyverse", 
  "tidyr",
  "ChainLadder",
  "boot",
  "dplyr"
)
invisible(lapply(required_libraries, library, character.only = TRUE))


## ----load-triangles-data, output=FALSE----------------------------------------
#| code-fold: true
#| code-summary: "Code for importing the dataset and transforming it into a triangle"

data("aids")

aids_agg <- aids |>
  group_by(year, quarter, delay) |>
  summarise(cases = sum(y), .groups = 'drop') |>
  mutate(year_quarter = paste(year, quarter, sep = "-"))

# Create a data frame in long format
aids_long <- aids_agg |>
  select(year_quarter, delay, cases)

# Reshape the data into a wide format (triangle format)
triangle <- aids_long |>
  pivot_wider(names_from = delay,
              values_from = cases,
              values_fill = list(cases = 0)) |>
  arrange(year_quarter)

# Convert the wide format data frame to a matrix
  triangle_matrix <- as.matrix(triangle |>
  select(-year_quarter))  # Exclude the year_quarter column for matrix conversion

rownames(triangle_matrix) <- triangle$year_quarter

# Triangular shape
n_rows <- nrow(triangle_matrix)
n_cols <- ncol(triangle_matrix)
  
for (i in seq_len(n_cols-1)) {
    triangle_matrix[(n_rows - i + 1):n_rows, i+1] <- NA
}

full_rows <- which(rowSums(is.na(triangle_matrix)) == 0)
full_triangle <- triangle_matrix[full_rows, ]
close_data <- colSums(full_triangle, na.rm = TRUE)

triangle_rows <- which(rowSums(is.na(triangle_matrix)) != 0)

triangle_matrix_final <- rbind(close_data, triangle_matrix[triangle_rows, ])

# Convert matrix to a 'triangle' object for chainladder
triangle_cl <- as.triangle(triangle_matrix_final)

print(triangle_cl)



## ----dev-chart----------------------------------------------------------------
#| code-fold: true

triangle_cum <- incr2cum(triangle_cl)
print(triangle_cum)


## ----TRIANGLES-plot-----------------------------------------------------------
#| fig-cap: "Claims development chart of the damage triangle, with one line per origin period."
#| label: "fig-dev-chart"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 8
#| fig-height: 5

ChainLadder::plot(as.triangle(triangle_cum[-1, -n_cols]))


## -----------------------------------------------------------------------------
#| fig-cap: "Claims development by origin year"
#| label: "fig-dev-origin"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 8
#| fig-height: 5

plot(as.triangle(triangle_cum[-1, -n_cols]), lattice=TRUE)


## ----MackChainLadder----------------------------------------------------------
#| code-fold: false

mack <- MackChainLadder(triangle_cum, est.sigma="Mack")
mack # same as summary(mack) 

## -----------------------------------------------------------------------------
#| code-fold: false
#| code-summary: Show the code

# Displaying the Mack model's parameters
mack$f

# Viewing the full triangle data from the Mack model
mack$FullTriangle

