## ----setup, message=FALSE, warning=FALSE--------------------------------------
#| code-fold: true
#| code-summary: "Session Settings"
#| label: load-packages

# Graphs----
face_text='plain'
face_title='plain'
size_title = 14
size_text = 11
legend_size = 11


## .justify {
##   text-align: justify !important
## }

## ----libraries, message=FALSE-------------------------------------------------

required_libraries <- c(
  "tidyverse", 
  "CASdatasets",
  "ChainLadder"
)
invisible(lapply(required_libraries, library, character.only = TRUE))


## ----load-triangles-data, output=FALSE----------------------------------------
#| code-fold: true
#| code-summary: "Code for importing our dataset"

data(fretri1auto9605)

Damage <- fretri1auto9605$damage$paid|>
  as.triangle()


## ----data-print---------------------------------------------------------------
#| code-fold: true

print(Damage)


## ----TRIANGLES-plot-----------------------------------------------------------
#| fig-cap: "Claims development chart of the damage triangle, with one line per origin period."
#| label: "fig-dev-chart"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 9
#| fig-height: 5

ChainLadder::plot(Damage/1000)


## ----plot-origin-year---------------------------------------------------------
#| fig-cap: "Claims development by origin year"
#| label: "fig-dev-origin"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 8
#| fig-height: 5

plot(Damage/1000, lattice=TRUE)


## ----MackChainLadder----------------------------------------------------------
#| code-fold: false

mack <- MackChainLadder(Damage, est.sigma="Mack")
mack # same as summary(mack) 

## ----fulltriangle-------------------------------------------------------------
#| code-fold: false
#| code-summary: Show the code

# Displaying the Mack model's parameters
mack$f

# Viewing the full triangle data from the Mack model
mack$FullTriangle


## ----Visualisation-mack, message = FALSE--------------------------------------
#| fig-cap: MackPlot
#| label: "fig-plot-Mack1"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 8
#| fig-height: 8

plot(mack)


## ----visualisation-mack-lattice-----------------------------------------------
#| fig-cap: MackPlot Lattice
#| label: "fig-plot-Mack2"
#| code-fold: true
#| code-summary: Code to create the following graph
#| fig-width: 8
#| fig-height: 5

plot(mack, lattice=TRUE)

